/* display-page.c generated by valac 0.20.1.16-ff48-dirty, the Vala compiler
 * generated from display-page.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <libgd/gd.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include <math.h>
#include <clutter/clutter.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <cairo.h>


#define BOXES_TYPE_DISPLAY_TOOLBAR (boxes_display_toolbar_get_type ())
#define BOXES_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar))
#define BOXES_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))
#define BOXES_IS_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_IS_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_DISPLAY_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))

typedef struct _BoxesDisplayToolbar BoxesDisplayToolbar;
typedef struct _BoxesDisplayToolbarClass BoxesDisplayToolbarClass;
typedef struct _BoxesDisplayToolbarPrivate BoxesDisplayToolbarPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block14Data Block14Data;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _Block15Data Block15Data;
typedef struct _Block16Data Block16Data;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;
typedef struct _BoxesDisplayPagePrivate BoxesDisplayPagePrivate;

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;

#define BOXES_TYPE_APP_PAGE (boxes_app_page_get_type ())

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block17Data Block17Data;

struct _BoxesDisplayToolbar {
	GdMainToolbar parent_instance;
	BoxesDisplayToolbarPrivate * priv;
};

struct _BoxesDisplayToolbarClass {
	GdMainToolbarClass parent_class;
};

struct _BoxesDisplayToolbarPrivate {
	gboolean overlay;
	GtkBox* leftbox;
	GtkBox* rightbox;
	gboolean button_down;
	gint button_down_x;
	gint button_down_y;
	guint button_down_button;
};

struct _Block14Data {
	int _ref_count_;
	BoxesDisplayToolbar * self;
	GtkButton* fullscreen;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _Block15Data {
	int _ref_count_;
	BoxesDisplayToolbar * self;
	GdkEventMotion event;
};

struct _Block16Data {
	int _ref_count_;
	Block15Data * _data15_;
	GtkWindow* window;
	gint old_width;
	gulong id;
};

struct _BoxesDisplayPage {
	GObject parent_instance;
	BoxesDisplayPagePrivate * priv;
};

struct _BoxesDisplayPageClass {
	GObjectClass parent_class;
};

struct _BoxesDisplayPagePrivate {
	GtkEventBox* event_box;
	GtkBox* box;
	BoxesDisplayToolbar* overlay_toolbar;
	GtkEventBox* overlay_toolbar_box;
	GtkGrid* notification_grid;
	BoxesDisplayToolbar* toolbar;
	guint toolbar_hide_id;
	guint toolbar_show_id;
	gulong cursor_id;
	guint overlay_toolbar_invisible_timeout;
	BoxesDisplay* display;
	gulong display_can_grab_id;
	gulong display_grabbed_id;
};

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_APP_PAGE_MAIN,
	BOXES_APP_PAGE_DISPLAY
} BoxesAppPage;

struct _Block17Data {
	int _ref_count_;
	BoxesDisplayPage * self;
	gulong draw_id;
	GtkWidget* widget;
};


static gpointer boxes_display_toolbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static gpointer boxes_display_page_parent_class = NULL;

GType boxes_display_toolbar_get_type (void) G_GNUC_CONST;
#define BOXES_DISPLAY_TOOLBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarPrivate))
enum  {
	BOXES_DISPLAY_TOOLBAR_DUMMY_PROPERTY
};
BoxesDisplayToolbar* boxes_display_toolbar_new (gboolean overlay);
BoxesDisplayToolbar* boxes_display_toolbar_construct (GType object_type, gboolean overlay);
static Block14Data* block14_data_ref (Block14Data* _data14_);
static void block14_data_unref (void * _userdata_);
static GtkButton* boxes_display_toolbar_add_image_button (BoxesDisplayToolbar* self, const gchar* icon_name, gboolean pack_start);
static void __lambda13_ (BoxesDisplayToolbar* self, GtkButton* button);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void ___lambda13__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda14_ (Block14Data* _data14_);
gboolean boxes_app_get_fullscreen (BoxesApp* self);
static void ___lambda14__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda15_ (BoxesDisplayToolbar* self, GtkButton* button);
void boxes_app_set_fullscreen (BoxesApp* self, gboolean value);
static void ___lambda15__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda16_ (BoxesDisplayToolbar* self, GtkButton* button);
static void ___lambda16__gtk_button_clicked (GtkButton* _sender, gpointer self);
static gboolean boxes_display_toolbar_real_button_press_event (GtkWidget* base, GdkEventButton* event);
static gboolean boxes_display_toolbar_real_button_release_event (GtkWidget* base, GdkEventButton* event);
static gboolean boxes_display_toolbar_real_motion_notify_event (GtkWidget* base, GdkEventMotion* event);
static Block15Data* block15_data_ref (Block15Data* _data15_);
static void block15_data_unref (void * _userdata_);
static Block16Data* block16_data_ref (Block16Data* _data16_);
static void block16_data_unref (void * _userdata_);
static void ____lambda17_ (Block16Data* _data16_);
static void _____lambda17__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_display_toolbar_finalize (GObject* obj);
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_display_get_type (void) G_GNUC_CONST;
#define BOXES_DISPLAY_PAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPagePrivate))
enum  {
	BOXES_DISPLAY_PAGE_DUMMY_PROPERTY,
	BOXES_DISPLAY_PAGE_WIDGET
};
static void boxes_display_page_toolbar_event_stop (BoxesDisplayPage* self);
BoxesDisplayPage* boxes_display_page_new (void);
BoxesDisplayPage* boxes_display_page_construct (GType object_type);
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
static gboolean __lambda18_ (BoxesDisplayPage* self, GdkEvent* event);
static gboolean _____lambda19_ (BoxesDisplayPage* self);
static void boxes_display_page_set_overlay_toolbar_visible (BoxesDisplayPage* self, gboolean visible);
static gboolean ______lambda19__gsource_func (gpointer self);
static gboolean _____lambda20_ (BoxesDisplayPage* self);
static gboolean ______lambda20__gsource_func (gpointer self);
static gboolean ___lambda18__gtk_widget_event (GtkWidget* _sender, GdkEvent* event, gpointer self);
static gboolean __lambda21_ (BoxesDisplayPage* self, GdkEventWindowState* event);
static void boxes_display_page_update_toolbar_visible (BoxesDisplayPage* self);
static gboolean ___lambda21__gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self);
void boxes_display_page_add_notification (BoxesDisplayPage* self, GtkWidget* w);
void boxes_display_page_get_size (BoxesDisplayPage* self, gint* width, gint* height);
static gboolean boxes_display_page_get_can_grab_mouse (BoxesDisplayPage* self);
void boxes_display_page_show (BoxesDisplayPage* self);
GType boxes_app_page_get_type (void) G_GNUC_CONST;
void boxes_display_page_update_title (BoxesDisplayPage* self);
GType boxes_machine_get_type (void) G_GNUC_CONST;
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
static gboolean boxes_display_page_get_grabbed (BoxesDisplayPage* self);
void boxes_display_page_show_display (BoxesDisplayPage* self, BoxesDisplay* display, GtkWidget* widget);
static Block17Data* block17_data_ref (Block17Data* _data17_);
static void block17_data_unref (void * _userdata_);
GtkWidget* boxes_display_page_remove_display (BoxesDisplayPage* self);
static void __lambda22_ (BoxesDisplayPage* self);
static gboolean __lambda23_ (BoxesDisplayPage* self);
static gboolean ___lambda23__gsource_func (gpointer self);
static void ___lambda22__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda24_ (BoxesDisplayPage* self);
static void ___lambda24__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean __lambda25_ (BoxesDisplayPage* self);
static gboolean ___lambda25__gsource_func (gpointer self);
static gboolean __lambda26_ (Block17Data* _data17_);
static void __lambda27_ (Block17Data* _data17_);
static void ___lambda27__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean ___lambda26__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self);
GtkWidget* boxes_display_page_get_widget (BoxesDisplayPage* self);
gboolean boxes_display_get_can_grab_mouse (BoxesDisplay* self);
gboolean boxes_display_get_mouse_grabbed (BoxesDisplay* self);
static void boxes_display_page_finalize (GObject* obj);
static void _vala_boxes_display_page_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


static Block14Data* block14_data_ref (Block14Data* _data14_) {
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_atomic_int_inc (&_data14_->_ref_count_);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return _data14_;
#line 477 "display-page.c"
}


static void block14_data_unref (void * _userdata_) {
	Block14Data* _data14_;
	_data14_ = (Block14Data*) _userdata_;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (g_atomic_int_dec_and_test (&_data14_->_ref_count_)) {
#line 486 "display-page.c"
		BoxesDisplayToolbar * self;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		self = _data14_->self;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_g_object_unref0 (_data14_->fullscreen);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_g_object_unref0 (self);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_slice_free (Block14Data, _data14_);
#line 496 "display-page.c"
	}
}


static void __lambda13_ (BoxesDisplayToolbar* self, GtkButton* button) {
	BoxesApp* _tmp0_;
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (button != NULL);
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_COLLECTION);
#line 509 "display-page.c"
}


static void ___lambda13__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	__lambda13_ (self, _sender);
#line 516 "display-page.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return self ? g_object_ref (self) : NULL;
#line 523 "display-page.c"
}


static void __lambda14_ (Block14Data* _data14_) {
	BoxesDisplayToolbar * self;
	GtkImage* image = NULL;
	GtkWidget* _tmp0_ = NULL;
	GtkImage* _tmp1_;
	BoxesApp* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = _data14_->self;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = gtk_button_get_image (_data14_->fullscreen);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GTK_TYPE_IMAGE) ? ((GtkImage*) _tmp0_) : NULL);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	image = _tmp1_;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = boxes_app_app;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = boxes_app_get_fullscreen (_tmp2_);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = _tmp3_;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp4_) {
#line 551 "display-page.c"
		GtkImage* _tmp5_;
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp5_ = image;
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_object_set (_tmp5_, "icon-name", "view-restore-symbolic", NULL);
#line 557 "display-page.c"
	} else {
		GtkImage* _tmp6_;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp6_ = image;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_object_set (_tmp6_, "icon-name", "view-fullscreen-symbolic", NULL);
#line 564 "display-page.c"
	}
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (image);
#line 568 "display-page.c"
}


static void ___lambda14__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	__lambda14_ (self);
#line 575 "display-page.c"
}


static void __lambda15_ (BoxesDisplayToolbar* self, GtkButton* button) {
	BoxesApp* _tmp0_;
	BoxesApp* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (button != NULL);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = boxes_app_app;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = boxes_app_get_fullscreen (_tmp1_);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = _tmp2_;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_app_set_fullscreen (_tmp0_, !_tmp3_);
#line 596 "display-page.c"
}


static void ___lambda15__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	__lambda15_ (self, _sender);
#line 603 "display-page.c"
}


static void __lambda16_ (BoxesDisplayToolbar* self, GtkButton* button) {
	BoxesApp* _tmp0_;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (button != NULL);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_PROPERTIES);
#line 615 "display-page.c"
}


static void ___lambda16__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	__lambda16_ (self, _sender);
#line 622 "display-page.c"
}


BoxesDisplayToolbar* boxes_display_toolbar_construct (GType object_type, gboolean overlay) {
	BoxesDisplayToolbar * self = NULL;
	Block14Data* _data14_;
	gboolean _tmp0_;
	gboolean _tmp1_;
	gint _tmp4_ = 0;
	gboolean _tmp5_;
	gint spacing = 0;
	gint _tmp6_;
	GtkBox* _tmp7_;
	GtkBox* _tmp8_;
	GtkBox* _tmp9_;
	GtkBox* _tmp10_;
	GtkButton* back = NULL;
	GtkButton* _tmp11_ = NULL;
	GtkButton* _tmp12_ = NULL;
	BoxesApp* _tmp13_;
	GtkButton* props = NULL;
	GtkButton* _tmp14_ = NULL;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data14_ = g_slice_new0 (Block14Data);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data14_->_ref_count_ = 1;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = (BoxesDisplayToolbar*) g_object_new (object_type, NULL);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data14_->self = g_object_ref (self);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_add_events ((GtkWidget*) self, (gint) GDK_POINTER_MOTION_MASK);
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = overlay;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->overlay = _tmp0_;
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = overlay;
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp1_) {
#line 663 "display-page.c"
		GtkStyleContext* _tmp2_ = NULL;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_style_context_add_class (_tmp2_, "osd");
#line 669 "display-page.c"
	} else {
		GtkStyleContext* _tmp3_ = NULL;
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp3_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_style_context_add_class (_tmp3_, GTK_STYLE_CLASS_MENUBAR);
#line 676 "display-page.c"
	}
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = overlay;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp5_) {
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = 0;
#line 684 "display-page.c"
	} else {
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = 12;
#line 688 "display-page.c"
	}
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = _tmp4_;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	spacing = _tmp6_;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp7_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, spacing);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp7_);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->leftbox);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->leftbox = _tmp7_;
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp8_ = self->priv->leftbox;
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gd_main_toolbar_add_widget ((GdMainToolbar*) self, (GtkWidget*) _tmp8_, TRUE);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp9_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, spacing);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp9_);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->rightbox);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->rightbox = _tmp9_;
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp10_ = self->priv->rightbox;
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gd_main_toolbar_add_widget ((GdMainToolbar*) self, (GtkWidget*) _tmp10_, FALSE);
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp11_ = boxes_display_toolbar_add_image_button (self, "go-previous-symbolic", TRUE);
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	back = _tmp11_;
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_signal_connect_object (back, "clicked", (GCallback) ___lambda13__gtk_button_clicked, self, 0);
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp12_ = boxes_display_toolbar_add_image_button (self, "view-fullscreen-symbolic", FALSE);
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data14_->fullscreen = _tmp12_;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp13_ = boxes_app_app;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_signal_connect_data ((GObject*) _tmp13_, "notify::fullscreen", (GCallback) ___lambda14__g_object_notify, block14_data_ref (_data14_), (GClosureNotify) block14_data_unref, G_CONNECT_AFTER);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_signal_connect_object (_data14_->fullscreen, "clicked", (GCallback) ___lambda15__gtk_button_clicked, self, 0);
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp14_ = boxes_display_toolbar_add_image_button (self, "preferences-system-symbolic", FALSE);
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	props = _tmp14_;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_signal_connect_object (props, "clicked", (GCallback) ___lambda16__gtk_button_clicked, self, 0);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (props);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (back);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	block14_data_unref (_data14_);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data14_ = NULL;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return self;
#line 750 "display-page.c"
}


BoxesDisplayToolbar* boxes_display_toolbar_new (gboolean overlay) {
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return boxes_display_toolbar_construct (BOXES_TYPE_DISPLAY_TOOLBAR, overlay);
#line 757 "display-page.c"
}


static GtkButton* boxes_display_toolbar_add_image_button (BoxesDisplayToolbar* self, const gchar* icon_name, gboolean pack_start) {
	GtkButton* result = NULL;
	GtkButton* button = NULL;
	GtkButton* _tmp0_;
	GtkImage* img = NULL;
	const gchar* _tmp1_;
	GtkImage* _tmp2_;
	GtkImage* _tmp3_;
	GtkButton* _tmp4_;
	GtkImage* _tmp5_;
	gboolean _tmp6_;
	gboolean _tmp11_;
	GtkButton* _tmp14_;
	GtkStyleContext* _tmp15_ = NULL;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (icon_name != NULL, NULL);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = (GtkButton*) gtk_button_new ();
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp0_);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	button = _tmp0_;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = icon_name;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = (GtkImage*) gtk_image_new_from_icon_name (_tmp1_, GTK_ICON_SIZE_MENU);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp2_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	img = _tmp2_;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = img;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_show ((GtkWidget*) _tmp3_);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = button;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = img;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_button_set_image (_tmp4_, (GtkWidget*) _tmp5_);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = pack_start;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp6_) {
#line 807 "display-page.c"
		GtkBox* _tmp7_;
		GtkButton* _tmp8_;
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp7_ = self->priv->leftbox;
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp8_ = button;
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_container_add ((GtkContainer*) _tmp7_, (GtkWidget*) _tmp8_);
#line 816 "display-page.c"
	} else {
		GtkBox* _tmp9_;
		GtkButton* _tmp10_;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp9_ = self->priv->rightbox;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp10_ = button;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_container_add ((GtkContainer*) _tmp9_, (GtkWidget*) _tmp10_);
#line 826 "display-page.c"
	}
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp11_ = self->priv->overlay;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (!_tmp11_) {
#line 832 "display-page.c"
		GtkButton* _tmp12_;
		GtkStyleContext* _tmp13_ = NULL;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp12_ = button;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp13_ = gtk_widget_get_style_context ((GtkWidget*) _tmp12_);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_style_context_add_class (_tmp13_, "raised");
#line 841 "display-page.c"
	}
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp14_ = button;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp15_ = gtk_widget_get_style_context ((GtkWidget*) _tmp14_);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_style_context_add_class (_tmp15_, "image-button");
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = button;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (img);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 855 "display-page.c"
}


static gboolean boxes_display_toolbar_real_button_press_event (GtkWidget* base, GdkEventButton* event) {
	BoxesDisplayToolbar * self;
	gboolean result = FALSE;
	gboolean res = FALSE;
	GdkEventButton _tmp0_;
	gboolean _tmp1_ = FALSE;
	GdkEvent* base_event = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_;
	gboolean _tmp6_;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = (BoxesDisplayToolbar*) base;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = *event;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = GTK_WIDGET_CLASS (boxes_display_toolbar_parent_class)->button_press_event ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gd_main_toolbar_get_type (), GdMainToolbar), &_tmp0_);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	res = _tmp1_;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	base_event = (GdkEvent*) (event);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = res;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (!_tmp3_) {
#line 885 "display-page.c"
		GdkEvent* _tmp4_;
		gboolean _tmp5_ = FALSE;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = base_event;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp5_ = gdk_event_triggers_context_menu (_tmp4_);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = !_tmp5_;
#line 894 "display-page.c"
	} else {
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = FALSE;
#line 898 "display-page.c"
	}
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = _tmp2_;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp6_) {
#line 904 "display-page.c"
		GdkEventButton _tmp7_;
		guint _tmp8_;
		GdkEventButton _tmp9_;
		gdouble _tmp10_;
		GdkEventButton _tmp11_;
		gdouble _tmp12_;
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		self->priv->button_down = TRUE;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp7_ = *event;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp8_ = _tmp7_.button;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		self->priv->button_down_button = _tmp8_;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp9_ = *event;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp10_ = _tmp9_.x;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		self->priv->button_down_x = (gint) _tmp10_;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp11_ = *event;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp12_ = _tmp11_.y;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		self->priv->button_down_y = (gint) _tmp12_;
#line 931 "display-page.c"
	}
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = res;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 937 "display-page.c"
}


static gboolean boxes_display_toolbar_real_button_release_event (GtkWidget* base, GdkEventButton* event) {
	BoxesDisplayToolbar * self;
	gboolean result = FALSE;
	GdkEventButton _tmp0_;
	gboolean _tmp1_ = FALSE;
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = (BoxesDisplayToolbar*) base;
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->button_down = FALSE;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = *event;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = GTK_WIDGET_CLASS (boxes_display_toolbar_parent_class)->button_press_event ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gd_main_toolbar_get_type (), GdMainToolbar), &_tmp0_);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = _tmp1_;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 960 "display-page.c"
}


static Block15Data* block15_data_ref (Block15Data* _data15_) {
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_atomic_int_inc (&_data15_->_ref_count_);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return _data15_;
#line 969 "display-page.c"
}


static void block15_data_unref (void * _userdata_) {
	Block15Data* _data15_;
	_data15_ = (Block15Data*) _userdata_;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (g_atomic_int_dec_and_test (&_data15_->_ref_count_)) {
#line 978 "display-page.c"
		BoxesDisplayToolbar * self;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		self = _data15_->self;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_g_object_unref0 (self);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_slice_free (Block15Data, _data15_);
#line 986 "display-page.c"
	}
}


static Block16Data* block16_data_ref (Block16Data* _data16_) {
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_atomic_int_inc (&_data16_->_ref_count_);
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return _data16_;
#line 996 "display-page.c"
}


static void block16_data_unref (void * _userdata_) {
	Block16Data* _data16_;
	_data16_ = (Block16Data*) _userdata_;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (g_atomic_int_dec_and_test (&_data16_->_ref_count_)) {
#line 1005 "display-page.c"
		BoxesDisplayToolbar * self;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		self = _data16_->_data15_->self;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_g_object_unref0 (_data16_->window);
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		block15_data_unref (_data16_->_data15_);
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_data16_->_data15_ = NULL;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_slice_free (Block16Data, _data16_);
#line 1017 "display-page.c"
	}
}


static void ____lambda17_ (Block16Data* _data16_) {
	Block15Data* _data15_;
	BoxesDisplayToolbar * self;
	gint root_x = 0;
	gint root_y = 0;
	gint width = 0;
	GtkWindow* _tmp0_;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	GtkWindow* _tmp3_;
	GdkWindow* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	GtkWindow* _tmp6_;
	guint _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
	gint _tmp10_;
	GdkEventMotion _tmp11_;
	guint32 _tmp12_;
	BoxesApp* _tmp13_;
	gulong _tmp14_;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data15_ = _data16_->_data15_;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = _data15_->self;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = _data16_->window;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_window_get_position (_tmp0_, &_tmp1_, &_tmp2_);
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	root_x = _tmp1_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	root_y = _tmp2_;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = _data16_->window;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = gtk_widget_get_window ((GtkWidget*) _tmp3_);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gdk_window_get_geometry (_tmp4_, NULL, NULL, &_tmp5_, NULL);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	width = _tmp5_;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = _data16_->window;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp7_ = self->priv->button_down_button;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp8_ = self->priv->button_down_x;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp9_ = _data16_->old_width;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp10_ = self->priv->button_down_y;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp11_ = _data15_->event;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp12_ = _tmp11_.time;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_window_begin_move_drag (_tmp6_, (gint) _tmp7_, root_x + ((gint) ((_tmp8_ / ((gdouble) _tmp9_)) * width)), root_y + _tmp10_, _tmp12_);
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp13_ = boxes_app_app;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp14_ = _data16_->id;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_signal_handler_disconnect ((GObject*) _tmp13_, _tmp14_);
#line 1085 "display-page.c"
}


static void _____lambda17__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	____lambda17_ (self);
#line 1092 "display-page.c"
}


static gboolean boxes_display_toolbar_real_motion_notify_event (GtkWidget* base, GdkEventMotion* event) {
	BoxesDisplayToolbar * self;
	gboolean result = FALSE;
	Block15Data* _data15_;
	GdkEventMotion _tmp0_;
	gboolean _tmp1_;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = (BoxesDisplayToolbar*) base;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data15_ = g_slice_new0 (Block15Data);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data15_->_ref_count_ = 1;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data15_->self = g_object_ref (self);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = *event;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data15_->event = _tmp0_;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = self->priv->button_down;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp1_) {
#line 1120 "display-page.c"
		gdouble dx = 0.0;
		GdkEventMotion _tmp2_;
		gdouble _tmp3_;
		gint _tmp4_;
		gdouble dy = 0.0;
		GdkEventMotion _tmp5_;
		gdouble _tmp6_;
		gint _tmp7_;
		gdouble _tmp8_;
		gdouble _tmp9_;
		gdouble _tmp10_;
		gdouble _tmp11_;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = _data15_->event;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp3_ = _tmp2_.x;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = self->priv->button_down_x;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		dx = _tmp3_ - _tmp4_;
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp5_ = _data15_->event;
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp6_ = _tmp5_.y;
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp7_ = self->priv->button_down_y;
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		dy = _tmp6_ - _tmp7_;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp8_ = dx;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp9_ = dx;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp10_ = dy;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp11_ = dy;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		if (((_tmp8_ * _tmp9_) + (_tmp10_ * _tmp11_)) > ((gdouble) (40 * 40))) {
#line 1159 "display-page.c"
			Block16Data* _data16_;
			BoxesApp* _tmp12_;
			GtkWidget* _tmp13_ = NULL;
			GtkWindow* _tmp14_;
			GtkWindow* _tmp15_;
			gint _tmp16_ = 0;
			BoxesApp* _tmp17_;
			gulong _tmp18_ = 0UL;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_data16_ = g_slice_new0 (Block16Data);
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_data16_->_ref_count_ = 1;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_data16_->_data15_ = block15_data_ref (_data15_);
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			self->priv->button_down = FALSE;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp12_ = boxes_app_app;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			boxes_app_set_fullscreen (_tmp12_, FALSE);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp13_ = gtk_widget_get_toplevel ((GtkWidget*) self);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GTK_TYPE_WINDOW) ? ((GtkWindow*) _tmp13_) : NULL);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_data16_->window = _tmp14_;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp15_ = _data16_->window;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			gtk_window_get_size (_tmp15_, &_tmp16_, NULL);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_data16_->old_width = _tmp16_;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_data16_->id = (gulong) 0;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp17_ = boxes_app_app;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp18_ = g_signal_connect_data ((GObject*) _tmp17_, "notify::fullscreen", (GCallback) _____lambda17__g_object_notify, block16_data_ref (_data16_), (GClosureNotify) block16_data_unref, 0);
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_data16_->id = _tmp18_;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			block16_data_unref (_data16_);
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_data16_ = NULL;
#line 1204 "display-page.c"
		}
	}
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (GTK_WIDGET_CLASS (boxes_display_toolbar_parent_class)->motion_notify_event != NULL) {
#line 1209 "display-page.c"
		GdkEventMotion _tmp19_;
		gboolean _tmp20_ = FALSE;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp19_ = _data15_->event;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp20_ = GTK_WIDGET_CLASS (boxes_display_toolbar_parent_class)->motion_notify_event ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gd_main_toolbar_get_type (), GdMainToolbar), &_tmp19_);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		result = _tmp20_;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		block15_data_unref (_data15_);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_data15_ = NULL;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		return result;
#line 1224 "display-page.c"
	}
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	block15_data_unref (_data15_);
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data15_ = NULL;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1234 "display-page.c"
}


static void boxes_display_toolbar_class_init (BoxesDisplayToolbarClass * klass) {
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_type_class_add_private (klass, sizeof (BoxesDisplayToolbarPrivate));
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	GTK_WIDGET_CLASS (klass)->button_press_event = boxes_display_toolbar_real_button_press_event;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	GTK_WIDGET_CLASS (klass)->button_release_event = boxes_display_toolbar_real_button_release_event;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	GTK_WIDGET_CLASS (klass)->motion_notify_event = boxes_display_toolbar_real_motion_notify_event;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_display_toolbar_finalize;
#line 1251 "display-page.c"
}


static void boxes_display_toolbar_instance_init (BoxesDisplayToolbar * self) {
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv = BOXES_DISPLAY_TOOLBAR_GET_PRIVATE (self);
#line 1258 "display-page.c"
}


static void boxes_display_toolbar_finalize (GObject* obj) {
	BoxesDisplayToolbar * self;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar);
#line 9 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->leftbox);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->rightbox);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (boxes_display_toolbar_parent_class)->finalize (obj);
#line 1272 "display-page.c"
}


GType boxes_display_toolbar_get_type (void) {
	static volatile gsize boxes_display_toolbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_display_toolbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDisplayToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_display_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDisplayToolbar), 0, (GInstanceInitFunc) boxes_display_toolbar_instance_init, NULL };
		GType boxes_display_toolbar_type_id;
		boxes_display_toolbar_type_id = g_type_register_static (gd_main_toolbar_get_type (), "BoxesDisplayToolbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_display_toolbar_type_id__volatile, boxes_display_toolbar_type_id);
	}
	return boxes_display_toolbar_type_id__volatile;
}


static gboolean _____lambda19_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_set_overlay_toolbar_visible (self, TRUE);
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->toolbar_show_id = (guint) 0;
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1298 "display-page.c"
}


static gboolean ______lambda19__gsource_func (gpointer self) {
	gboolean result;
	result = _____lambda19_ (self);
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1307 "display-page.c"
}


static gboolean _____lambda20_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
	BoxesApp* _tmp0_;
	guint _tmp1_;
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_set_overlay_toolbar_visible (self, FALSE);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->toolbar_hide_id = (guint) 0;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = _tmp0_->duration;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->overlay_toolbar_invisible_timeout = _tmp1_;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1329 "display-page.c"
}


static gboolean ______lambda20__gsource_func (gpointer self) {
	gboolean result;
	result = _____lambda20_ (self);
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1338 "display-page.c"
}


static gboolean __lambda18_ (BoxesDisplayPage* self, GdkEvent* event) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	BoxesApp* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp6_;
	GdkEvent* _tmp26_;
	GdkEventType _tmp27_;
	GtkEventBox* _tmp28_;
	GtkWidget* _tmp29_ = NULL;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = boxes_app_app;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = boxes_app_get_fullscreen (_tmp1_);
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = _tmp2_;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp3_) {
#line 1363 "display-page.c"
		GdkEvent* _tmp4_;
		GdkEventType _tmp5_;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = event;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp5_ = _tmp4_->type;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp5_ == GDK_MOTION_NOTIFY;
#line 1372 "display-page.c"
	} else {
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 1376 "display-page.c"
	}
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = _tmp0_;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp6_) {
#line 1382 "display-page.c"
		gdouble y = 0.0;
		GdkEvent* _tmp7_;
		GdkEventMotion _tmp8_;
		gdouble _tmp9_;
		gboolean _tmp10_ = FALSE;
		gdouble _tmp11_;
		gboolean _tmp13_;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp7_ = event;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp8_ = _tmp7_->motion;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp9_ = _tmp8_.y;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		y = _tmp9_;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp11_ = y;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		if (_tmp11_ <= ((gdouble) 0)) {
#line 1402 "display-page.c"
			guint _tmp12_;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp12_ = self->priv->toolbar_show_id;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp10_ = _tmp12_ == ((guint) 0);
#line 1408 "display-page.c"
		} else {
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp10_ = FALSE;
#line 1412 "display-page.c"
		}
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp13_ = _tmp10_;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		if (_tmp13_) {
#line 1418 "display-page.c"
			GdkEvent* _tmp14_;
			GdkEventMotion _tmp15_;
			GdkModifierType _tmp16_;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			boxes_display_page_toolbar_event_stop (self);
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp14_ = event;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp15_ = _tmp14_->motion;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp16_ = _tmp15_.state;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			if ((_tmp16_ & ((((((((((GDK_SHIFT_MASK | GDK_CONTROL_MASK) | GDK_MOD1_MASK) | GDK_SUPER_MASK) | GDK_HYPER_MASK) | GDK_META_MASK) | GDK_BUTTON1_MASK) | GDK_BUTTON2_MASK) | GDK_BUTTON3_MASK) | GDK_BUTTON4_MASK) | GDK_BUTTON5_MASK)) == 0) {
#line 1432 "display-page.c"
				BoxesApp* _tmp17_;
				guint _tmp18_;
				guint _tmp19_ = 0U;
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp17_ = boxes_app_app;
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp18_ = _tmp17_->duration;
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp19_ = g_timeout_add_full (G_PRIORITY_DEFAULT, _tmp18_, ______lambda19__gsource_func, g_object_ref (self), g_object_unref);
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
				self->priv->toolbar_show_id = _tmp19_;
#line 1444 "display-page.c"
			}
		} else {
			gboolean _tmp20_ = FALSE;
			gdouble _tmp21_;
			gboolean _tmp23_;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp21_ = y;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			if (_tmp21_ > ((gdouble) 5)) {
#line 1454 "display-page.c"
				guint _tmp22_;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp22_ = self->priv->toolbar_hide_id;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp20_ = _tmp22_ == ((guint) 0);
#line 1460 "display-page.c"
			} else {
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp20_ = FALSE;
#line 1464 "display-page.c"
			}
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp23_ = _tmp20_;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
			if (_tmp23_) {
#line 1470 "display-page.c"
				guint _tmp24_;
				guint _tmp25_ = 0U;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
				boxes_display_page_toolbar_event_stop (self);
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp24_ = self->priv->overlay_toolbar_invisible_timeout;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp25_ = g_timeout_add_full (G_PRIORITY_DEFAULT, _tmp24_, ______lambda20__gsource_func, g_object_ref (self), g_object_unref);
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
				self->priv->toolbar_hide_id = _tmp25_;
#line 1481 "display-page.c"
			}
		}
	}
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp26_ = event;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp27_ = _tmp26_->type;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp27_ == GDK_GRAB_BROKEN) {
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		result = FALSE;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		return result;
#line 1495 "display-page.c"
	}
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp28_ = self->priv->event_box;
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp29_ = gtk_bin_get_child ((GtkBin*) _tmp28_);
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp29_ != NULL) {
#line 1503 "display-page.c"
		GtkEventBox* _tmp30_;
		GtkWidget* _tmp31_ = NULL;
		GdkEvent* _tmp32_;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp30_ = self->priv->event_box;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp31_ = gtk_bin_get_child ((GtkBin*) _tmp30_);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp32_ = event;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_widget_event (_tmp31_, _tmp32_);
#line 1515 "display-page.c"
	}
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1521 "display-page.c"
}


static gboolean ___lambda18__gtk_widget_event (GtkWidget* _sender, GdkEvent* event, gpointer self) {
	gboolean result;
	result = __lambda18_ (self, event);
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1530 "display-page.c"
}


static gboolean __lambda21_ (BoxesDisplayPage* self, GdkEventWindowState* event) {
	gboolean result = FALSE;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_toolbar_visible (self);
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1544 "display-page.c"
}


static gboolean ___lambda21__gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self) {
	gboolean result;
	result = __lambda21_ (self, event);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1553 "display-page.c"
}


BoxesDisplayPage* boxes_display_page_construct (GType object_type) {
	BoxesDisplayPage * self = NULL;
	BoxesApp* _tmp0_;
	guint _tmp1_;
	GtkEventBox* _tmp2_;
	GtkEventBox* _tmp3_;
	GtkStyleContext* _tmp4_ = NULL;
	GtkEventBox* _tmp5_;
	GtkEventBox* _tmp6_;
	GtkEventBox* _tmp7_;
	BoxesDisplayToolbar* _tmp8_;
	GtkBox* _tmp9_;
	GtkBox* _tmp10_;
	BoxesDisplayToolbar* _tmp11_;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp12_;
	BoxesApp* _tmp13_;
	GtkApplicationWindow* _tmp14_;
	GtkEventBox* _tmp15_;
	GtkEventBox* _tmp16_;
	GtkBox* _tmp17_;
	BoxesDisplayToolbar* _tmp18_;
	GtkEventBox* _tmp19_;
	GtkEventBox* _tmp20_;
	BoxesDisplayToolbar* _tmp21_;
	GtkEventBox* _tmp22_;
	GtkEventBox* _tmp23_;
	GtkGrid* _tmp24_;
	GtkGrid* _tmp25_;
	GtkGrid* _tmp26_;
	GtkGrid* _tmp27_;
	GtkEventBox* _tmp28_;
	GtkEventBox* _tmp29_;
	GtkGrid* _tmp30_;
	GtkBox* _tmp31_;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = (BoxesDisplayPage*) g_object_new (object_type, NULL);
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = _tmp0_->duration;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->overlay_toolbar_invisible_timeout = _tmp1_;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = (GtkEventBox*) gtk_event_box_new ();
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp2_);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->event_box);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->event_box = _tmp2_;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = self->priv->event_box;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = gtk_widget_get_style_context ((GtkWidget*) _tmp3_);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_style_context_add_class (_tmp4_, "boxes-toplevel");
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = self->priv->event_box;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_events ((GtkWidget*) _tmp5_, (gint) (GDK_POINTER_MOTION_MASK | GDK_SCROLL_MASK));
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = self->priv->event_box;
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_event_box_set_above_child (_tmp6_, TRUE);
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp7_ = self->priv->event_box;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_signal_connect_object ((GtkWidget*) _tmp7_, "event", (GCallback) ___lambda18__gtk_widget_event, self, 0);
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp8_ = boxes_display_toolbar_new (FALSE);
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp8_);
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->toolbar);
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->toolbar = _tmp8_;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp9_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp9_);
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->box);
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->box = _tmp9_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp10_ = self->priv->box;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp11_ = self->priv->toolbar;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_box_pack_start (_tmp10_, (GtkWidget*) _tmp11_, FALSE, FALSE, (guint) 0);
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp12_ = (GtkGrid*) gtk_grid_new ();
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp12_);
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	grid = _tmp12_;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp13_ = boxes_app_app;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp14_ = _tmp13_->window;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_signal_connect_object ((GtkWidget*) _tmp14_, "window-state-event", (GCallback) ___lambda21__gtk_widget_window_state_event, self, 0);
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp15_ = self->priv->event_box;
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _tmp15_, TRUE);
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp16_ = self->priv->event_box;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_vexpand ((GtkWidget*) _tmp16_, TRUE);
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp17_ = self->priv->box;
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_box_pack_start (_tmp17_, (GtkWidget*) grid, TRUE, TRUE, (guint) 0);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp18_ = boxes_display_toolbar_new (TRUE);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp18_);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->overlay_toolbar);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->overlay_toolbar = _tmp18_;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp19_ = (GtkEventBox*) gtk_event_box_new ();
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp19_);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->overlay_toolbar_box);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->overlay_toolbar_box = _tmp19_;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp20_ = self->priv->overlay_toolbar_box;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp21_ = self->priv->overlay_toolbar;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_container_add ((GtkContainer*) _tmp20_, (GtkWidget*) _tmp21_);
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp22_ = self->priv->overlay_toolbar_box;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp22_, GTK_ALIGN_START);
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp23_ = self->priv->overlay_toolbar_box;
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_vexpand ((GtkWidget*) _tmp23_, FALSE);
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp24_ = (GtkGrid*) gtk_grid_new ();
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp24_);
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->notification_grid);
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->notification_grid = _tmp24_;
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp25_ = self->priv->notification_grid;
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp25_, GTK_ALIGN_START);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp26_ = self->priv->notification_grid;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp26_, GTK_ALIGN_CENTER);
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp27_ = self->priv->notification_grid;
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_vexpand ((GtkWidget*) _tmp27_, TRUE);
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp28_ = self->priv->event_box;
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp28_, 0, 0, 1, 2);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp29_ = self->priv->overlay_toolbar_box;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp29_, 0, 0, 1, 1);
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp30_ = self->priv->notification_grid;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp30_, 0, 1, 1, 1);
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp31_ = self->priv->box;
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp31_);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (grid);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return self;
#line 1742 "display-page.c"
}


BoxesDisplayPage* boxes_display_page_new (void) {
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return boxes_display_page_construct (BOXES_TYPE_DISPLAY_PAGE);
#line 1749 "display-page.c"
}


void boxes_display_page_add_notification (BoxesDisplayPage* self, GtkWidget* w) {
	GtkGrid* _tmp0_;
	GtkWidget* _tmp1_;
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (w != NULL);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->notification_grid;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = w;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_grid_attach (_tmp0_, _tmp1_, 0, 0, 1, 1);
#line 1766 "display-page.c"
}


void boxes_display_page_get_size (BoxesDisplayPage* self, gint* width, gint* height) {
	gint _vala_width = 0;
	gint _vala_height = 0;
	gint tb_height = 0;
	BoxesApp* _tmp0_;
	GtkApplicationWindow* _tmp1_;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	BoxesApp* _tmp4_;
	gboolean _tmp5_;
	gboolean _tmp6_;
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 235 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 235 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = _tmp0_->window;
#line 235 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_window_get_size ((GtkWindow*) _tmp1_, &_tmp2_, &_tmp3_);
#line 235 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_vala_width = _tmp2_;
#line 235 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_vala_height = _tmp3_;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = boxes_app_app;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = boxes_app_get_fullscreen (_tmp4_);
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = _tmp5_;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (!_tmp6_) {
#line 1801 "display-page.c"
		BoxesDisplayToolbar* _tmp7_;
		gint _tmp8_ = 0;
		gint _tmp9_;
		gint _tmp10_;
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp7_ = self->priv->toolbar;
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_widget_get_preferred_height ((GtkWidget*) _tmp7_, NULL, &_tmp8_);
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		tb_height = _tmp8_;
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp9_ = _vala_height;
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp10_ = tb_height;
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_vala_height = _tmp9_ - _tmp10_;
#line 1818 "display-page.c"
	}
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (width) {
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		*width = _vala_width;
#line 1824 "display-page.c"
	}
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (height) {
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		*height = _vala_height;
#line 1830 "display-page.c"
	}
}


static void boxes_display_page_update_toolbar_visible (BoxesDisplayPage* self) {
	gboolean _tmp0_ = FALSE;
	BoxesApp* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp6_;
#line 243 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = boxes_app_app;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = boxes_app_get_fullscreen (_tmp1_);
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = _tmp2_;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp3_) {
#line 1851 "display-page.c"
		gboolean _tmp4_;
		gboolean _tmp5_;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = boxes_display_page_get_can_grab_mouse (self);
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp5_ = _tmp4_;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = !_tmp5_;
#line 1860 "display-page.c"
	} else {
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 1864 "display-page.c"
	}
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = _tmp0_;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp6_) {
#line 1870 "display-page.c"
		BoxesDisplayToolbar* _tmp7_;
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp7_ = self->priv->toolbar;
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_widget_set_visible ((GtkWidget*) _tmp7_, FALSE);
#line 1876 "display-page.c"
	} else {
		BoxesDisplayToolbar* _tmp8_;
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp8_ = self->priv->toolbar;
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_widget_set_visible ((GtkWidget*) _tmp8_, TRUE);
#line 1883 "display-page.c"
	}
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_set_overlay_toolbar_visible (self, FALSE);
#line 1887 "display-page.c"
}


static void boxes_display_page_set_overlay_toolbar_visible (BoxesDisplayPage* self, gboolean visible) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
	gboolean _tmp5_;
	GtkEventBox* _tmp6_;
	gboolean _tmp7_;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = visible;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp1_) {
#line 1903 "display-page.c"
		BoxesDisplayToolbar* _tmp2_;
		gboolean _tmp3_;
		gboolean _tmp4_;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->priv->toolbar;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp3_ = gtk_widget_get_visible ((GtkWidget*) _tmp2_);
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = _tmp3_;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp4_;
#line 1915 "display-page.c"
	} else {
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 1919 "display-page.c"
	}
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = _tmp0_;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp5_) {
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_debug ("display-page.vala:254: toolbar is visible, don't show overlay toolbar");
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		return;
#line 1929 "display-page.c"
	}
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = self->priv->overlay_toolbar_box;
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp7_ = visible;
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp6_, _tmp7_);
#line 1937 "display-page.c"
}


static void boxes_display_page_toolbar_event_stop (BoxesDisplayPage* self) {
	guint _tmp0_;
	guint _tmp2_;
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->toolbar_hide_id;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp0_ != ((guint) 0)) {
#line 1950 "display-page.c"
		guint _tmp1_;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp1_ = self->priv->toolbar_hide_id;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_source_remove (_tmp1_);
#line 1956 "display-page.c"
	}
#line 268 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->toolbar_hide_id = (guint) 0;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = self->priv->toolbar_show_id;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp2_ != ((guint) 0)) {
#line 1964 "display-page.c"
		guint _tmp3_;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp3_ = self->priv->toolbar_show_id;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_source_remove (_tmp3_);
#line 1970 "display-page.c"
	}
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->toolbar_show_id = (guint) 0;
#line 1974 "display-page.c"
}


void boxes_display_page_show (BoxesDisplayPage* self) {
	BoxesApp* _tmp0_;
	GtkNotebook* _tmp1_;
#line 274 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = _tmp0_->notebook;
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_set (_tmp1_, "page", (gint) BOXES_APP_PAGE_DISPLAY, NULL);
#line 1989 "display-page.c"
}


void boxes_display_page_update_title (BoxesDisplayPage* self) {
	BoxesMachine* machine = NULL;
	BoxesApp* _tmp0_;
	BoxesCollectionItem* _tmp1_;
	BoxesMachine* _tmp2_;
	BoxesMachine* _tmp3_;
	gchar* title = NULL;
	BoxesMachine* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* hint = NULL;
	gboolean _tmp8_;
	gboolean _tmp9_;
	BoxesDisplayToolbar* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	BoxesDisplayToolbar* _tmp15_;
	const gchar* _tmp16_;
	const gchar* _tmp17_;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = _tmp0_->current_item;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp1_) : NULL);
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	machine = _tmp2_;
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = machine;
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (_tmp3_ != NULL);
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = machine;
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp4_);
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = _tmp5_;
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp7_ = g_strdup (_tmp6_);
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	title = _tmp7_;
#line 283 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	hint = NULL;
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp8_ = boxes_display_page_get_grabbed (self);
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp9_ = _tmp8_;
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp9_) {
#line 2045 "display-page.c"
		const gchar* _tmp10_ = NULL;
		gchar* _tmp11_;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp10_ = _ ("(press Ctrl+Alt keys to ungrab)");
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp11_ = g_strdup (_tmp10_);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_g_free0 (hint);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		hint = _tmp11_;
#line 2056 "display-page.c"
	}
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp12_ = self->priv->overlay_toolbar;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp13_ = title;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp14_ = hint;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gd_main_toolbar_set_labels ((GdMainToolbar*) _tmp12_, _tmp13_, _tmp14_);
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp15_ = self->priv->toolbar;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp16_ = title;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp17_ = hint;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gd_main_toolbar_set_labels ((GdMainToolbar*) _tmp15_, _tmp16_, _tmp17_);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_free0 (hint);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_free0 (title);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (machine);
#line 2080 "display-page.c"
}


static Block17Data* block17_data_ref (Block17Data* _data17_) {
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_atomic_int_inc (&_data17_->_ref_count_);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return _data17_;
#line 2089 "display-page.c"
}


static void block17_data_unref (void * _userdata_) {
	Block17Data* _data17_;
	_data17_ = (Block17Data*) _userdata_;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (g_atomic_int_dec_and_test (&_data17_->_ref_count_)) {
#line 2098 "display-page.c"
		BoxesDisplayPage * self;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		self = _data17_->self;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_g_object_unref0 (_data17_->widget);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_g_object_unref0 (self);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_slice_free (Block17Data, _data17_);
#line 2108 "display-page.c"
	}
}


static gboolean __lambda23_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_title (self);
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 2121 "display-page.c"
}


static gboolean ___lambda23__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda23_ (self);
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 2130 "display-page.c"
}


static void __lambda22_ (BoxesDisplayPage* self) {
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_idle_add_full (G_PRIORITY_HIGH, ___lambda23__gsource_func, g_object_ref (self), g_object_unref);
#line 2137 "display-page.c"
}


static void ___lambda22__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	__lambda22_ (self);
#line 2144 "display-page.c"
}


static void __lambda24_ (BoxesDisplayPage* self) {
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_toolbar_visible (self);
#line 2151 "display-page.c"
}


static void ___lambda24__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	__lambda24_ (self);
#line 2158 "display-page.c"
}


static gboolean __lambda25_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
	BoxesApp* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_toolbar_visible (self);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->overlay_toolbar_invisible_timeout = (guint) 1000;
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = boxes_app_get_fullscreen (_tmp0_);
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = _tmp1_;
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_set_overlay_toolbar_visible (self, _tmp2_);
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 2183 "display-page.c"
}


static gboolean ___lambda25__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda25_ (self);
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 2192 "display-page.c"
}


static void __lambda27_ (Block17Data* _data17_) {
	BoxesDisplayPage * self;
	GtkEventBox* _tmp0_;
	GdkWindow* _tmp1_ = NULL;
	GtkWidget* _tmp2_;
	GdkWindow* _tmp3_ = NULL;
	GdkCursor* _tmp4_;
	GdkCursor* _tmp5_;
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = _data17_->self;
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->event_box;
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = gtk_widget_get_window ((GtkWidget*) _tmp0_);
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = _data17_->widget;
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = gtk_widget_get_window (_tmp2_);
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = gdk_window_get_cursor (_tmp3_);
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = _tmp4_;
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gdk_window_set_cursor (_tmp1_, _tmp5_);
#line 2220 "display-page.c"
}


static void ___lambda27__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	__lambda27_ (self);
#line 2227 "display-page.c"
}


static gboolean __lambda26_ (Block17Data* _data17_) {
	BoxesDisplayPage * self;
	gboolean result = FALSE;
	GtkWidget* _tmp0_;
	gulong _tmp1_;
	GtkWidget* _tmp2_;
	GdkWindow* _tmp3_ = NULL;
	gulong _tmp4_ = 0UL;
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = _data17_->self;
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = _data17_->widget;
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = _data17_->draw_id;
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _tmp1_);
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = _data17_->widget;
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = gtk_widget_get_window (_tmp2_);
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = g_signal_connect_data ((GObject*) _tmp3_, "notify::cursor", (GCallback) ___lambda27__g_object_notify, block17_data_ref (_data17_), (GClosureNotify) block17_data_unref, 0);
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->cursor_id = _tmp4_;
#line 333 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 333 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 2259 "display-page.c"
}


static gboolean ___lambda26__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self) {
	gboolean result;
	result = __lambda26_ (self);
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 2268 "display-page.c"
}


void boxes_display_page_show_display (BoxesDisplayPage* self, BoxesDisplay* display, GtkWidget* widget) {
	Block17Data* _data17_;
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	GtkEventBox* _tmp2_;
	GtkWidget* _tmp3_ = NULL;
	GtkWidget* _tmp4_;
	GtkWidget* _tmp5_ = NULL;
	GtkWidget* _tmp6_;
	BoxesDisplay* _tmp7_;
	BoxesDisplay* _tmp8_;
	BoxesDisplay* _tmp9_;
	gulong _tmp10_ = 0UL;
	BoxesDisplay* _tmp11_;
	gulong _tmp12_ = 0UL;
	GtkWidget* _tmp13_;
	GtkWidget* _tmp14_;
	gint _tmp15_ = 0;
	GtkEventBox* _tmp16_;
	GtkWidget* _tmp17_;
	GtkEventBox* _tmp18_;
	GtkWidget* _tmp19_;
	gulong _tmp20_ = 0UL;
	GtkWidget* _tmp21_;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (display != NULL);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (widget != NULL);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data17_ = g_slice_new0 (Block17Data);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data17_->_ref_count_ = 1;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data17_->self = g_object_ref (self);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = widget;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (_data17_->widget);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data17_->widget = _tmp1_;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = self->priv->event_box;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = gtk_bin_get_child ((GtkBin*) _tmp2_);
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = _data17_->widget;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp3_ == _tmp4_) {
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		block17_data_unref (_data17_);
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_data17_ = NULL;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		return;
#line 2330 "display-page.c"
	}
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = boxes_display_page_remove_display (self);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = _tmp5_;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (_tmp6_);
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp7_ = display;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->display);
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->display = _tmp8_;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp9_ = display;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp10_ = g_signal_connect_object ((GObject*) _tmp9_, "notify::mouse-grabbed", (GCallback) ___lambda22__g_object_notify, self, 0);
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->display_grabbed_id = _tmp10_;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_toolbar_visible (self);
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp11_ = display;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp12_ = g_signal_connect_object ((GObject*) _tmp11_, "notify::can-grab-mouse", (GCallback) ___lambda24__g_object_notify, self, 0);
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->display_can_grab_id = _tmp12_;
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda25__gsource_func, g_object_ref (self), g_object_unref);
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_title (self);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp13_ = _data17_->widget;
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp14_ = _data17_->widget;
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp15_ = gtk_widget_get_events (_tmp14_);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_events (_tmp13_, _tmp15_ & (~GDK_POINTER_MOTION_MASK));
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp16_ = self->priv->event_box;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp17_ = _data17_->widget;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_container_add ((GtkContainer*) _tmp16_, _tmp17_);
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp18_ = self->priv->event_box;
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp18_);
#line 325 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data17_->draw_id = (gulong) 0;
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp19_ = _data17_->widget;
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp20_ = g_signal_connect_data (_tmp19_, "draw", (GCallback) ___lambda26__gtk_widget_draw, block17_data_ref (_data17_), (GClosureNotify) block17_data_unref, 0);
#line 326 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data17_->draw_id = _tmp20_;
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_show (self);
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp21_ = _data17_->widget;
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_grab_focus (_tmp21_);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	block17_data_unref (_data17_);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data17_ = NULL;
#line 2400 "display-page.c"
}


GtkWidget* boxes_display_page_remove_display (BoxesDisplayPage* self) {
	GtkWidget* result = NULL;
	gulong _tmp0_;
	gulong _tmp3_;
	GtkWidget* widget = NULL;
	GtkEventBox* _tmp6_;
	GtkWidget* _tmp7_ = NULL;
	GtkWidget* _tmp8_;
	gulong _tmp9_;
	GtkWidget* _tmp13_;
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->display_grabbed_id;
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 2420 "display-page.c"
		BoxesDisplay* _tmp1_;
		gulong _tmp2_;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp1_ = self->priv->display;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->priv->display_grabbed_id;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_signal_handler_disconnect ((GObject*) _tmp1_, _tmp2_);
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		self->priv->display_grabbed_id = (gulong) 0;
#line 2431 "display-page.c"
	}
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = self->priv->display_can_grab_id;
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp3_ != ((gulong) 0)) {
#line 2437 "display-page.c"
		BoxesDisplay* _tmp4_;
		gulong _tmp5_;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = self->priv->display;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp5_ = self->priv->display_can_grab_id;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_signal_handler_disconnect ((GObject*) _tmp4_, _tmp5_);
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		self->priv->display_can_grab_id = (gulong) 0;
#line 2448 "display-page.c"
	}
#line 351 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = self->priv->event_box;
#line 351 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp7_ = gtk_bin_get_child ((GtkBin*) _tmp6_);
#line 351 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 351 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	widget = _tmp8_;
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp9_ = self->priv->cursor_id;
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp9_ != ((gulong) 0)) {
#line 2462 "display-page.c"
		GtkWidget* _tmp10_;
		GdkWindow* _tmp11_ = NULL;
		gulong _tmp12_;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp10_ = widget;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp11_ = gtk_widget_get_window (_tmp10_);
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp12_ = self->priv->cursor_id;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_signal_handler_disconnect ((GObject*) _tmp11_, _tmp12_);
#line 355 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		self->priv->cursor_id = (gulong) 0;
#line 2476 "display-page.c"
	}
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp13_ = widget;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp13_ != NULL) {
#line 2482 "display-page.c"
		GtkEventBox* _tmp14_;
		GtkWidget* _tmp15_;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp14_ = self->priv->event_box;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp15_ = widget;
#line 359 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_container_remove ((GtkContainer*) _tmp14_, _tmp15_);
#line 2491 "display-page.c"
	}
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = widget;
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 2497 "display-page.c"
}


GtkWidget* boxes_display_page_get_widget (BoxesDisplayPage* self) {
	GtkWidget* result;
	GtkBox* _tmp0_;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->box;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = (GtkWidget*) _tmp0_;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 2512 "display-page.c"
}


static gboolean boxes_display_page_get_can_grab_mouse (BoxesDisplayPage* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	BoxesDisplay* _tmp1_;
	gboolean _tmp5_;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = self->priv->display;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp1_ != NULL) {
#line 2527 "display-page.c"
		BoxesDisplay* _tmp2_;
		gboolean _tmp3_;
		gboolean _tmp4_;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->priv->display;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp3_ = boxes_display_get_can_grab_mouse (_tmp2_);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = _tmp3_;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp4_;
#line 2539 "display-page.c"
	} else {
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 2543 "display-page.c"
	}
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = _tmp0_;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = _tmp5_;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 2551 "display-page.c"
}


static gboolean boxes_display_page_get_grabbed (BoxesDisplayPage* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	BoxesDisplay* _tmp1_;
	gboolean _tmp5_;
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = self->priv->display;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp1_ != NULL) {
#line 2566 "display-page.c"
		BoxesDisplay* _tmp2_;
		gboolean _tmp3_;
		gboolean _tmp4_;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->priv->display;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp3_ = boxes_display_get_mouse_grabbed (_tmp2_);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = _tmp3_;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp4_;
#line 2578 "display-page.c"
	} else {
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 2582 "display-page.c"
	}
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = _tmp0_;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = _tmp5_;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 2590 "display-page.c"
}


static void boxes_display_page_class_init (BoxesDisplayPageClass * klass) {
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_parent_class = g_type_class_peek_parent (klass);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_type_class_add_private (klass, sizeof (BoxesDisplayPagePrivate));
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_display_page_get_property;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_display_page_finalize;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_PAGE_WIDGET, g_param_spec_object ("widget", "widget", "widget", GTK_TYPE_WIDGET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 2605 "display-page.c"
}


static void boxes_display_page_instance_init (BoxesDisplayPage * self) {
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv = BOXES_DISPLAY_PAGE_GET_PRIVATE (self);
#line 2612 "display-page.c"
}


static void boxes_display_page_finalize (GObject* obj) {
	BoxesDisplayPage * self;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage);
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_toolbar_event_stop (self);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->event_box);
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->box);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->overlay_toolbar);
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->overlay_toolbar_box);
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->notification_grid);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->toolbar);
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->display);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (boxes_display_page_parent_class)->finalize (obj);
#line 2638 "display-page.c"
}


GType boxes_display_page_get_type (void) {
	static volatile gsize boxes_display_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_display_page_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDisplayPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_display_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDisplayPage), 0, (GInstanceInitFunc) boxes_display_page_instance_init, NULL };
		GType boxes_display_page_type_id;
		boxes_display_page_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesDisplayPage", &g_define_type_info, 0);
		g_once_init_leave (&boxes_display_page_type_id__volatile, boxes_display_page_type_id);
	}
	return boxes_display_page_type_id__volatile;
}


static void _vala_boxes_display_page_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesDisplayPage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
	switch (property_id) {
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		case BOXES_DISPLAY_PAGE_WIDGET:
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_value_set_object (value, boxes_display_page_get_widget (self));
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		break;
#line 2665 "display-page.c"
		default:
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/display-page.vala"
		break;
#line 2671 "display-page.c"
	}
}



